@@ -1,7 +1,11 @@
+# encoding: utf-8
+
+from __future__ import absolute_import
+
 import pydoc
 import sys
 
-from bpython.pager import page
+from .pager import page
 
 # Ugly monkeypatching
 pydoc.pager = page
