@@ -7,38 +7,32 @@ from bpython.test import unittest
 
 
 class TestSimpleComplete(unittest.TestCase):
+
     def setUp(self):
         self.original_modules = importcompletion.modules
-        importcompletion.modules = [
-            "zzabc",
-            "zzabd",
-            "zzefg",
-            "zzabc.e",
-            "zzabc.f",
-        ]
+        importcompletion.modules = ['zzabc', 'zzabd', 'zzefg', 'zzabc.e',
+                                    'zzabc.f']
 
     def tearDown(self):
         importcompletion.modules = self.original_modules
 
     def test_simple_completion(self):
-        self.assertSetEqual(
-            importcompletion.complete(10, "import zza"), set(["zzabc", "zzabd"])
-        )
+        self.assertSetEqual(importcompletion.complete(10, 'import zza'),
+                            set(['zzabc', 'zzabd']))
 
     def test_package_completion(self):
-        self.assertSetEqual(
-            importcompletion.complete(13, "import zzabc."),
-            set(["zzabc.e", "zzabc.f"]),
-        )
+        self.assertSetEqual(importcompletion.complete(13, 'import zzabc.'),
+                            set(['zzabc.e', 'zzabc.f']))
 
 
 class TestRealComplete(unittest.TestCase):
+
     @classmethod
     def setUpClass(cls):
         for _ in importcompletion.find_iterator:
             pass
-        __import__("sys")
-        __import__("os")
+        __import__('sys')
+        __import__('os')
 
     @classmethod
     def tearDownClass(cls):
@@ -47,15 +41,13 @@ class TestRealComplete(unittest.TestCase):
 
     def test_from_attribute(self):
         self.assertSetEqual(
-            importcompletion.complete(19, "from sys import arg"), set(["argv"])
-        )
+            importcompletion.complete(19, 'from sys import arg'),
+            set(['argv']))
 
     def test_from_attr_module(self):
-        self.assertSetEqual(
-            importcompletion.complete(9, "from os.p"), set(["os.path"])
-        )
+        self.assertSetEqual(importcompletion.complete(9, 'from os.p'),
+                            set(['os.path']))
 
     def test_from_package(self):
-        self.assertSetEqual(
-            importcompletion.complete(17, "from xml import d"), set(["dom"])
-        )
+        self.assertSetEqual(importcompletion.complete(17, 'from xml import d'),
+                            set(['dom']))
